#
# spec file for package python-pyzmq
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Disable tests, they are so slow that OBS thinks the build died.
%bcond_with tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pyzmq
Version:        17.0.0
Release:        bp153.1.16
Summary:        Python bindings for 0MQ
License:        LGPL-3.0+ and BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://github.com/zeromq/pyzmq
Source:         https://files.pythonhosted.org/packages/source/p/pyzmq/pyzmq-%{version}.tar.gz
Source1:        python-pyzmq-rpmlintrc
# PATCH-FIX-OPENSUSE skip_test_tracker.patch
Patch1:         skip_test_tracker.patch
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module cffi}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module gevent}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module paramiko}
BuildRequires:  %{python_module pexpect}
BuildRequires:  %{python_module py}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module simplejson}
BuildRequires:  %{python_module tornado}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  zeromq-devel
# Test requirements
BuildRequires:  %{python_module nose}
Requires:       python
Recommends:     python-cffi
Recommends:     python-gevent
Recommends:     python-numpy
Recommends:     python-pexpect
Recommends:     python-py
Recommends:     python-simplejson
Recommends:     python-tornado
Recommends:     python-paramiko
Recommends:     zeromq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%python_subpackages

%description
PyZMQ is a lightweight and super-fast messaging library built on top of
the ZeroMQ library (http://www.zeromq.org).

%package devel
Summary:        Development files for %{name}
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       python-devel
Requires:       zeromq-devel

%description devel
Development libraries and headers needed to build software using %{name}.

%prep
%setup -q -n pyzmq-%{version}
# Fix non-executable script rpmlint warning:
find examples zmq -name "*.py" -exec sed -i "s|#\!\/usr\/bin\/env python||" {} \;

%patch1

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%if %{with tests}
%check
# Remove non-deterministic authentication test
# This fails to connect randomly
rm -rf zmq/tests/test_auth.py

%python_exec setup.py build_ext --inplace
%python_exec setup.py test
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc AUTHORS.md COPYING.BSD COPYING.LESSER README.md examples
%{python_sitearch}/zmq/
%{python_sitearch}/pyzmq-%{version}-py*.egg-info
%exclude %{python_sitearch}/zmq/utils/*.h
%exclude %{python_sitearch}/zmq/backend/cffi/_verify.c
%exclude %{python_sitearch}/zmq/backend/cffi/_cdefs.h

%files %{python_files devel}
%defattr(-,root,root,-)
%{python_sitearch}/zmq/utils/*.h
%{python_sitearch}/zmq/backend/cffi/_verify.c
%{python_sitearch}/zmq/backend/cffi/_cdefs.h

%changelog
* Sat Feb 10 2018 arun@gmx.de
- update to version 17.0.0:
  * Add :meth:`zmq.Socket.send_serialized` and
    :meth:`zmq.Socket.recv_serialized` for sending/receiving messages
    with custom serialization.
  * Add :attr:`zmq.Socket.copy_threshold` and
    :const:`zmq.COPY_THRESHOLD`. Messages smaller than this are always
    copied, regardless of copy=False, to avoid overhead of zero-copy
    bookkeeping on small messages.
  * Added visible deprecation warnings to bundled tornado
    IOLoop. Tornado eventloop integration shouldn't be used without a
    proper tornado install since pyzmq 14.
  * Allow pyzmq asyncio/tornado integration to run without installing
    :func:`zmq_poll` implementation. The following methods and classes
    are deprecated and no longer required:
    :func:`zmq.eventloop.ioloop.install`
    :class:`zmq.eventloop.ioloop.IOLoop`
    :func:`zmq.asyncio.install`
    :class:`zmq.asyncio.ZMQEventLoop`
  * Set RPATH correctly when building on macOS.
  * Compatibility fixes with tornado 5.0.dev (may not be quite enough
    for 5.0 final, which is not yet released as of pyzmq 17).
  * Draft support for CLIENT-SERVER routing_id and group.
* Sun Jan 28 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 16.0.4:
  * Regenerate Cython sources in sdists with Cython 0.27.3, fixing
    builds on CPython 3.7.
  * Add warning when using bundled tornado, which was deprecated too
    quietly in 14.x.
* Thu Nov  2 2017 arun@gmx.de
- update to version 16.0.3:
  * Regenerate Cython sources in sdists with Cython 0.27.2, fixing
    builds on CPython 3.7.
* Sun Aug  6 2017 toddrme2178@gmail.com
- Remove docs. They aren't being built so they are not useful,
  and they break the build.
* Fri Apr 14 2017 toddrme2178@gmail.com
- Update to 16.0.2
- Rebase skip_test_tracker.patch.
- Implement single-spec version.
* Tue Jan 26 2016 toddrme2178@gmail.com
- update to version 15.2.0:
  * FIX: handle multiple events in a single register call in
    :mod:`zmq.asyncio`
  * FIX: unicode/bytes bug in password prompt in :mod:`zmq.ssh` on
    Python 3
  * FIX: workaround gevent monkeypatches in garbage collection thread
  * update bundled minitornado from tornado-4.3.
  * improved inspection by setting binding=True in cython compile
    options
  * add asyncio Authenticator implementation in
    :mod:`zmq.auth.asyncio`
  * workaround overflow bug in libzmq preventing receiving messages
    larger than MAX_INT
- update to version 15.1.0:
  * FIX: Remove inadvertant tornado dependency when using
    :mod:`zmq.asyncio`
  * FIX: 15.0 Python 3.5 wheels didn't work on Windows
  * Add GSSAPI support to Authenticators
  * Support new constants defined in upcoming libzmq-4.2.dev
- update to version 15.0.0:
  * add :mod:`asyncio` support via :mod:`zmq.asyncio`
  * add :mod:`tornado` future support via :mod:`zmq.eventloop.future`
  * trigger bundled libzmq if system libzmq is found to be < 3. System
    libzmq 2 can be forced by explicitly requesting --zmq=/prefix/.
* Tue Sep  8 2015 aplanas@suse.com
- Add patch skip_test_tracker.patch to skip test_tracker test.
  This test block the VM in OBS for a long period of time, causing
  the kill of the VM and the fail in the RPM creation.
* Wed Jul 29 2015 toddrme2178@gmail.com
- Add additional optional dependencies that support additional
  features and/or additional backends.
* Wed Jul 15 2015 toddrme2178@gmail.com
- Include authors and BSD license in source
* Mon Jul 13 2015 aboe76@gmail.com
- Update to 14.7.0
  + Changes:
  * Update bundled libzmq to 4.1.2.
  * Following the lead of Python 3.5, interrupted system calls will be retried.
  + Bugfixes:
  * Fixes for CFFI backend on Python 3 + support for PyPy 3.
  * Verify types of all frames in :meth:`~zmq.Socket.send_multipart`
    before sending, to avoid partial messages.
  * Fix build on Windows when both debug and release versions of libzmq are found.
- Update to 14.6.0
  + Changes:
  * improvements in :meth:`zmq.Socket.bind_to_random_port`:
  - Use system to allocate ports by default
  * pyzmq no longer bundles external libzmq when making a bdist.
    You can use delocate to do this.
  + Bugfixes:
  * add missing :attr:`ndim` on memoryviews of Frames
  * allow :func:`copy.copy` and :func:`copy.deepcopy` on Sockets, Contexts
* Mon Mar 16 2015 p.drouand@gmail.com
- Update download Url
* Mon Mar 16 2015 hpj@urpla.net
- Update to 14.5.0
  + Changes:
  * use pickle.DEFAULT_PROTOCOL by default in send_pickle
  * with the release of pip-6, OS X wheels are only marked as 10.6-intel,
    indicating that they should be installable on any newer or single-arch Python.
  * raise SSHException on failed check of host key
  + Bugfixes:
  * fix method name in utils.wi32.allow_interrupt
  * fork-related fixes in garbage collection thread
  * add missing import in zmq.__init__, causing failure to import in some circumstances
- Update to 14.4.1
  + Bugfixes
  * SyntaxError on Python 2.6 in zmq.ssh
  * Handle possible bug in garbage collection after fork
- Update to 14.4.0
  + New features
  * Experimental support for libzmq-4.1.0 rc (new constants, plus zmq.has()).
  * Update bundled libzmq to 4.0.5
  * Update bundled libsodium to 1.0.0
  * Fixes for SSH dialogs when using zmq.ssh to create tunnels
  * More build/link/load fixes on OS X and Solaris
  * Get Frame metadata via dict access (libzmq 4)
  * Contexts and Sockets are context managers (term/close on __exit__)
  * Add zmq.utils.win32.allow_interrupt context manager for catching SIGINT on Windows
  + Bugfixes:
  * Bundled libzmq should not trigger recompilation after install on PyPy
* Wed Oct  1 2014 toddrme2178@gmail.com
- Update to 14.3.1
  + Minor bugfixes to pyzmq 14.3:
  * Fixes to building bundled libzmq on OS X < 10.9
  * Fixes to import-failure warnings on Python 3.4
  * Fixes to tests
  * Pull upstream fixes to zmq.ssh for ssh multiplexing
- Update to 14.3.0
  + PyZMQ no longer calls :meth:`.Socket.close` or
    :meth:`.Context.term` during process cleanup.
    Changes to garbage collection in Python 3.4 make this
    impossible to do sensibly.
  + :meth:`ZMQStream.close` closes its socket immediately,
    rather than scheduling a timeout.
  + Raise the original ImportError when importing zmq fails.
    Should be more informative than `no module cffi...`.
- Update to 14.2.0
  + New Stuff
  * Raise new ZMQVersionError when a requested method is not
    supported by the linked libzmq.
    For backward compatibility, this subclasses
    NotImplementedError.
  + Bugs Fixed
  * Memory leak introduced in pyzmq-14.0 in zero copy.
  * OverflowError on 32 bit systems in zero copy.
- Update to 14.1.0
  + Security
    The headline features for 14.1 are adding better support for
    libzmq's security features.
  * When libzmq is bundled as a Python extension
    (e.g. wheels, eggs), libsodium is also bundled
    (excluding Windows), ensuring that libzmq security is
    available to users who install from wheels
  * New :mod:`zmq.auth`, implementing zeromq's ZAP authentication,
    modeled on czmq zauth.
    For more information, see the
    `examples <https://github.com/zeromq/pyzmq/tree/master/examples/>`_.
  + Other New Stuff
  * Add PYZMQ_BACKEND for enabling use of backends outside the
    pyzmq codebase.
  * Add :attr:`~.Context.underlying` property and
    :meth:`~.Context.shadow` method to Context and Socket, for
    handing off sockets and contexts. between pyzmq and other
    bindings (mainly pyczmq_).
  * Add TOS, ROUTER_HANDOVER, and IPC_FILTER constants from
    libzmq-4.1-dev.
  * Add Context option support in the CFFI backend.
  * Various small unicode and build fixes, as always.
  * :meth:`~.Socket.send_json` and :meth:`~.Socket.recv_json`
    pass any extra kwargs to ``json.dumps/loads``.
  + Deprecations
  * ``Socket.socket_type`` is deprecated, in favor of
    ``Socket.type``, which has been available since 2.1.
- Update to 14.0.1
  + Bugfix release
  * Update bundled libzmq to current (4.0.3).
  * Fix bug in :meth:`.Context.destroy` with no open sockets.
  * Threadsafety fixes in the garbage collector.
  * Python 3 fixes in :mod:`zmq.ssh`.
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Wed Feb 12 2014 dmueller@suse.com
- disable testsuite for qemu-linux-user builds
* Sun Nov 24 2013 p.drouand@gmail.com
- Update to version 14.0.0
  + Update bundled libzmq to current (4.0.1).
  + Backends are now implemented in ``zmq.backend`` instead of ``zmq.core``.
    This has no effect on public APIs.
  + Various build improvements for Cython and CFFI backends (PyPy
    compiles at build time).
  + Various GIL-related performance improvements - the GIL is no longer
    touched from a zmq IO thread.
  + Adding a constant should now be a bit easier - only zmq/sugar/constant
  _names should need updating,
    all other constant-related files should be automatically updated by
    ``setup.py constants``.
  + add support for latest libzmq-4.0.1
    (includes ZMQ_CURVE security and socket event monitoring).
- Changes from version 13.1.0
  + The main new feature is improved tornado 3 compatibility.
    PyZMQ ships a 'minitornado' submodule, which contains a small
    subset of tornado 3.0.1,
    in order to get the IOLoop base class.  zmq.eventloop.ioloop.IOLoop
    is now a simple subclass, and if the system tornado is ≥ 3.0, then
    the zmq IOLoop is a proper registered subclass of the tornado one itself,
    and minitornado is entirely unused.
- Changes from version 13.0.2
  + EAGAIN was unconditionally turned into KeyboardInterrupt
  + fix use of totally deprecated ctypes_configure to generate constants in CFFI backend
  + fix memory leak in CFFI backend for PyPy
  + typo prevented IPC_PATH_MAX_LEN from ever being defined
  + various build fixes - linking with librt, Cython compatibility, etc.
* Fri Apr 12 2013 toddrme2178@gmail.com
- Changes suggests to recommends since there is no way to install suggets currently
* Fri Apr  5 2013 cfarrell@suse.com
- license update: LGPL-3.0+ and BSD-3-Clause
  the core is LGPL-3.0+ but most of what is outside the code is
  BSD-3-Clause
* Wed Mar 27 2013 speilicke@suse.com
- Update to version 13.0.0:
  + PyPy support
  + The Threadsafe ZMQStream experiment in 2.2.0.1 was deemed inappropriate and not useful,
    and has been removed.
  + The zmq.web experiment has been removed, to be developed as a standalone project
  + Fixes bnc#811890
- Add rpmlintrc
- Drop useless macros
- Run testsuite
* Fri May 18 2012 toddrme2178@gmail.com
- Fix rpmlint warnings
* Fri Apr 27 2012 highwaystar.ru@gmail.com
- fixed building of python3 package on openSUSE 11.4 and older
* Tue Mar 27 2012 saschpe@suse.de
- Update to version 2.1.11:
  * remove support for LABEL prefixes. A major feature of libzmq-3.0, the LABEL
    prefix, has been removed from libzmq, prior to the first stable libzmq 3.x release.
  * The prefix argument to ~.Socket.send_multipart remains, but it continue to behave in
    exactly the same way as it always has on 2.1.x, simply prepending message parts.
  * ~.Socket.recv_multipart will always return a list, because prefixes are once
    again indistinguishable from regular message parts.
  * add .Socket.poll method, for simple polling of events on a single socket.
  * no longer require monkeypatching tornado IOLoop.  The :class:.ioloop.ZMQPoller class
    is a poller implementation that matches tornado's expectations, and pyzmq sockets can
    be used with any tornado application just by specifying the use of this poller. The
    pyzmq IOLoop implementation now only trivially differs from tornado's.
- Don't package documentation sources
* Tue Jan 31 2012 saschpe@suse.de
- Update to version 2.1.11:
  * remove support for LABEL prefixes.
  * add :meth:`.Socket.poll` method, for simple polling of events on a single socket.
  * no longer require monkeypatching tornado IOLoop.
- Moved Python-3 package into seperate spec file
* Mon Dec  5 2011 toddrme2178@gmail.com
- Cleaned up spec file formatting
- Added python3 subpackage
* Mon Sep 26 2011 cfarrell@suse.com
- license update: LGPL-3.0+
  LGPL is not a recognized license
* Fri Aug 19 2011 saschpe@suse.de
- Update to version 2.1.7:
  * Added proper GIL management for non-copying send
  * Implemented support for zmq_errno().
  * Added Socket.create_socket()
  * Fixed setup.py to work with libzmq.dll on Window
  * The flags argument to Socket.send/Socket.recv must be a C int
    to prevent Python-C API calls in the nogil section.
  * Added a protocol argument to pyobj_send that defaults to -1 (the
    highest pickle protocol).
  * Added a try/finally in Socket.recv.
* Sun Dec 12 2010 saschpe@gmx.de
- Re-generated with py2pack
  * now builds for all RPM-based distros
* Wed Dec  1 2010 saschpe@suse.de
- Initial version (2.0.10).
